// This module helps get the notification object in a plain text format, which could be printed to the console or a file
use crate::notification::Notification;

impl Notification {
    // Actions, plain text format
    pub fn actions_plain(&self) -> String {
        if self.actions().is_empty() {
            "None".to_string()
        } else {
            self.actions()
                .iter()
                .fold(String::new(), |mut acc, (id, label)| {
                    // The formatted string is appended to the accumulator string, acc
                    acc.push_str(&format!("\n\t{id}: {label}"));
                    acc
                })
        }
    }

    // Default action, as plain text
    pub fn default_action_plain(&self) -> String {
        match self.default_action() {
            None => "None".to_string(),
            Some(actn) => actn.0,
        }
    }

    // Hints, as plain text
    pub fn hints_plain(&self) -> String {
        if self.hints().is_empty() {
            "None".to_string()
        } else {
            self.hints()
                .iter()
                .fold(String::new(), |mut acc, (key, value)| {
                    acc.push_str(&format!("\n\t{}: {}", key, **value));
                    acc
                })
        }
    }

    // Return the notification as a plain string
    pub fn plain(&self) -> String {
        let plain_string: String = format!("App Name: {}\nReplace ID: {}\nIcon: {}\nSummary: {}\nBody: {}\nActions: {}\nHints: {}\nExpiration Timeout: {}\nUrgency: {}\nDefault Action: {}",
                        &self.app_name(),
                        &self.replace_id(),
                        &self.icon(),
                        &self.summary(),
                        &self.body(),
                        &self.actions_plain(),
                        &self.hints_plain(),
                        &self.expir_timeout(),
                        &self.urgency(),
                        &self.default_action_plain(),
                    );
        plain_string
    }
}
